Exception
==========================

.. currentmodule:: xgrammar

.. autoclass:: xgrammar.DeserializeFormatError
.. autoclass:: xgrammar.DeserializeVersionError
.. autoclass:: xgrammar.InvalidJSONError
